import json
import logging

from pyleague.domain.participants import n_of_participants
from pyleague.infrastructure.path_utils import get_project_root_path


def generate_day_pointer(participants):
    logging.debug("Generating day pointer")
    number_of_participants = len(participants)
    number_of_days = number_of_participants - 1
    day_pointer = (0, number_of_days)
    return day_pointer


def store_day_pointer(day_pointer):
    logging.debug("Storing day pointer")
    root = get_project_root_path()
    day_pointer_path = root / "files" / "day_pointer.json"
    with open(day_pointer_path, "w") as day_pointer_file:
        json.dump(day_pointer, day_pointer_file)


def read_day_pointer():
    logging.debug("Reading day pointer")
    root = get_project_root_path()
    day_pointer_path = root / "files" / "day_pointer.json"
    with open(day_pointer_path, "r") as day_pointer_file:
        day_pointer = json.load(day_pointer_file)
    return day_pointer


def modify_day_pointer(day_pointer, next_):
    logging.debug("Modifying day pointer")
    if next_:
        day_pointer[0] += 1
        day_pointer[0] %= n_of_participants() - 1
    else:
        day_pointer[0] -= 1
        day_pointer[0] %= n_of_participants() - 1
    return day_pointer



import json
import logging

from pyleague.infrastructure.path_utils import get_project_root_path


def ask_for_participants():
    participants = list()
    i = 0
    while True:
        participant = input(f"Insert participant {i} or type 'done' to continue: ")
        if participant == "":
            break
        if participant == "done":
            break
        else:
            participants.append(participant)
            i += 1

    number_of_participants = len(participants)
    if number_of_participants % 2 != 0:
        participants.append("No one")

    return participants


def store_participants(participants):
    logging.debug("Storing participants ...")
    root = get_project_root_path()
    participants_file_path = root / "files" / "participants.json"
    with open(participants_file_path, "w") as participants_file:
        json.dump(participants, participants_file)


def read_participants():
    logging.debug("Reading participants ...")
    root = get_project_root_path()
    participants_file_path = root / "files" / "participants.json"
    with open(participants_file_path, "r") as participants_file:
        participants = json.load(participants_file)
    return participants


def n_of_participants():
    return len(read_participants())


def print_participants(participants):
    print("Participants: ")
    for participant in participants:
        print(participant)



import typer

from pyleague.domain.day_pointer import generate_day_pointer, store_day_pointer, read_day_pointer, modify_day_pointer
from pyleague.domain.groups_per_day import generate_groups_per_day, store_groups_per_day, read_group
from pyleague.domain.participants import ask_for_participants, store_participants, read_participants, print_participants

app = typer.Typer()


@app.command()
def init():
    # ask for participants
    participants = ask_for_participants()
    # store participants
    store_participants(participants)
    # generate groups per day
    groups_per_day = generate_groups_per_day(participants)
    # store groups per day
    store_groups_per_day(groups_per_day)
    # generate day pointer
    day_pointer = generate_day_pointer(participants)
    # store day pointer
    store_day_pointer(day_pointer)


def print_day_and_group(day_pointer, group):
    number_of_participants = len(group)

    pairs = list()
    for i in range(int(number_of_participants / 2)):
        pairs.append(f"{group[i]} VS {group[-i - 1]}")

    print(f"Day: {day_pointer[0]}")
    print("")
    for pair in pairs:
        print(pair)


@app.command()
def previous():
    # read day pointer
    day_pointer = read_day_pointer()
    # modify day pointer
    day_pointer = modify_day_pointer(day_pointer, next_=False)
    # store modified day pointer
    store_day_pointer(day_pointer)
    # read corresponding group
    group = read_group(day_pointer)
    # print corresponding day and group
    print_day_and_group(day_pointer, group)


@app.command()
def today():
    # read day pointer
    day_pointer = read_day_pointer()
    # read corresponding group
    group = read_group(day_pointer)
    # print corresponding day and group
    print_day_and_group(day_pointer, group)


@app.command()
def next():
    # read day pointer
    day_pointer = read_day_pointer()
    # modify day pointer
    day_pointer = modify_day_pointer(day_pointer, next_=True)
    # store modified day pointer
    store_day_pointer(day_pointer)
    # read corresponding group
    group = read_group(day_pointer)
    # print corresponding day and group
    print_day_and_group(day_pointer, group)


@app.command()
def participants():
    # read participants
    my_participants = read_participants()
    # print participants
    print_participants(my_participants)


if __name__ == "__main__":
    app()



from pyleague.entrypoint.main import generate_groups_per_day


def test_generate_groups_per_day_works_correctly_for_4_participants():
    participants = ["a", "b", "c", "d"]
    groups_per_day = generate_groups_per_day(participants)
    expected_groups_per_day = [
        ['a', 'b', 'c', 'd'],
        ['a', 'd', 'b', 'c'],
        ['a', 'c', 'd', 'b'],
    ]
    assert groups_per_day == expected_groups_per_day


def test_generate_groups_per_day_works_correctly_for_6_participants():
    participants = ["a", "b", "c", "d", "e", "f"]
    groups_per_day = generate_groups_per_day(participants)
    expected_groups_per_day = [['a', 'b', 'c', 'd', 'e', 'f'],
                               ['a', 'f', 'b', 'c', 'd', 'e'],
                               ['a', 'e', 'f', 'b', 'c', 'd'],
                               ['a', 'd', 'e', 'f', 'b', 'c'],
                               ['a', 'c', 'd', 'e', 'f', 'b']]
    assert groups_per_day == expected_groups_per_day



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pyleague',
 'pyleague.domain',
 'pyleague.entrypoint',
 'pyleague.infrastructure',
 'pyleague.tests']

package_data = \
{'': ['*'], 'pyleague': ['files/*']}

install_requires = \
['typer>=0.7.0,<0.8.0']

entry_points = \
{'console_scripts': ['pyleague = pyleague.entrypoint.main:app']}

setup_kwargs = {
    'name': 'pyleague',
    'version': '0.1.0',
    'description': "Pyleague is a cli tool that helps organizing competitions. After providing pyleague with a list of the competition's participants you will be able to get the matches for each day of the competition.",
    'long_description': '# Pyleague\n\n## Index\n\n1. [Overview](#overview)\n2. [Requirements](#requirements)\n3. [Installation](#installation)\n4. [Configuration](#configuration)\n5. [Tests](#tests)\n6. [Deployment](#deployment)\n   7.[Getting started:](#getting_started)\n\n## <a name="overview">Overview</a>\n\nPyleague is a cli tool that helps organizing competitions.\nAfter providing pyleague with a list of the competition\'s participants\nyou will be able to get the matches for each day of the competition.\n\n## <a name="requirements">Requirements</a>\n\n* System requirements\n\npython >= 3.9\n\n* Package requirements\n\nListed in pyproject.toml under \'[tool.poetry.dependencies]\'\n\n## <a name="installation">Installation</a>\n\n### For use\n\nFetch it from pip\n\n```bash\npip install pyleague\n```\n\n### For development\n\nTo install package dependencies, install [poetry](https://python-poetry.org/docs/), then run the following command:\n\n```bash\npoetry install\n```\n\n## <a name="tests">Tests</a>\n\nFrom root directory run:\n\n~~~\npytest pyleague/tests\n~~~\n\n## <a name="deployment">Deployment</a>\n\nUse poetry\n\n```commandline\npoetry build\n```\n\n```commandline\npoetry publish\n```\n\n## <a name="getting_started">Getting started</a>\n\nTo try the app:\n\n* Install it\n\n* On your terminal run\n\n```commandline\npyleague init\n```\n\nDefine your league participants as asked.\n\n* Check the matches for today\n\n```commandline\npyleague today\n```\n\n* Update the league to the next day\n\n```commandline\npyleague next\n```\n\n```commandline\npyleague today\n```\n',
    'author': 'mf-andres',
    'author_email': 'amunoz@gradiant.org',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/mf-andres/pyleague',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)



import json
import logging

from pyleague.infrastructure.path_utils import get_project_root_path


def generate_groups_per_day(participants):
    logging.debug("Generating groups per day")
    number_of_participants = len(participants)
    number_of_days = number_of_participants - 1

    fixed_player = participants[0]
    rotating_players = participants[1:]
    groups_per_day = list()
    for i in range(int(number_of_days)):
        group = [fixed_player] + rotating_players
        groups_per_day.append(group)
        rotating_players = [rotating_players[-1]] + rotating_players[:-1]
    return groups_per_day


def store_groups_per_day(groups_per_day):
    logging.debug("Storing groups per day")
    root = get_project_root_path()
    groups_per_day_file_path = root / "files" / "groups_per_day.json"
    with open(groups_per_day_file_path, "w") as groups_per_day_file:
        json.dump(groups_per_day, groups_per_day_file)


def read_group(day_pointer):
    logging.debug("Reading group")
    root = get_project_root_path()
    groups_per_day_file_path = root / "files" / "groups_per_day.json"
    with open(groups_per_day_file_path, "r") as groups_per_day_file:
        groups_per_day = json.load(groups_per_day_file)
    group = groups_per_day[day_pointer[0]]
    return group
